==> fine-web-0.0.1-20220919.091035-231.jar: beetlsql/base/dic.md <==
select
===
select @pageTag(){
T.*,
GETDICNAME('DATA_STATUS', T.IS_ENABLE) AS ENABLE_NAME,
GETDICNAME('DIC_TYPE', T.DIC_TYPE) AS DIC_TYPE_NAME,
NVL(S1.USENUM,0)AS USENUM
 @}
FROM BAS_DIC T
LEFT JOIN (SELECT S.DIC_CODE, COUNT(S.DIC_CODE) AS USENUM
              FROM GEN_PANEL_ITEM S
             WHERE S.DIC_CODE IS NOT NULL
             GROUP BY S.DIC_CODE) S1
  ON S1.DIC_CODE = T.DIC_CODE
@where(){ 
	@if(!isEmpty(typeId)){
			and t.type_id=#typeId#
	@}
	@if(!isEmpty(search)){
		and ( upper(t.dic_code) like #search# ESCAPE '/' 
		or upper(t.dic_name) like  #search#  ESCAPE '/' 
		or upper(t.dic_value) like #search#  ESCAPE '/' 
		or upper(t.dic_text) like #search#  ESCAPE '/' 
		or upper(t.memo) like #search#  ESCAPE '/' )
	@}
@}
ORDER BY T.DIC_CODE, t.is_enable,T.DISPLAY_NO, T.DIC_VALUE


findByTypeId
===
select * from BAS_DIC t where t.type_id=#typeId#




pageAllType
===
select @pageTag(){
t.*,
GETDICNAME('IS_OR_NOT', T.FLAG) AS FLAG_TEXT,
GETDICNAME('IS_OR_NOT', T.USER_EDIT) AS USER_EDIT_TEXT,
GETDICNAME('DIC_TYPE', T.DIC_TYPE) AS DIC_TYPE_TEXT,
p.name business_Type,
NVL(S1.USENUM,0)AS USENUM
@}
 from BAS_DIC_TYPE t
LEFT JOIN (SELECT S.DIC_CODE, COUNT(S.DIC_CODE) AS USENUM
              FROM GEN_PANEL_ITEM S
             WHERE S.DIC_CODE IS NOT NULL
             GROUP BY S.DIC_CODE) S1
  ON S1.DIC_CODE = T.DIC_CODE
 left join STF_BUSINESS_TYPE p on p.res_id = t.business_Type_Id
 @if(!isEmpty(search)){
		,(
		(select x.dic_code from BAS_DIC_TYPE x where upper(x.dic_code) like #search#  ESCAPE '/' )
		union 
		(select x.dic_code from BAS_DIC_TYPE x where upper(x.dic_name) like #search#  ESCAPE '/' )
		union 
		(select x.dic_code from BAS_DIC_TYPE x where upper(x.RMK) like #search#  ESCAPE '/' )
		union 
		(select x.dic_code from BAS_DIC_TYPE x where upper(x.RMK) like #search#  ESCAPE '/' )
		union 
		(select d.dic_code from bas_dic d where upper(d.dic_text) like #search#  ESCAPE '/' or upper(d.dic_value) like #search#  ESCAPE '/' )
		) x 
	@}
 where t.is_use='Y'
 @if(!isEmpty(search)){
	 and t.dic_code =x.dic_code
 @}
@if(!isEmpty(businessTypeId)){
	and t.business_Type_Id = #businessTypeId#
@}
 
 ORDER BY T.ord_By
 
 
 
getWbsType
===
select 
       t.DIC_ID ID，
       t.DIC_VALUE VALUE,
       t.DIC_TEXT TEXT
       from BAS_DIC t
       where t.DIC_CODE = 'WBS_TYPE'
       @if(!isEmpty(id)){
       		and  t.DIC_VALUE >= #id#
       	@}
       	
findDicValueByName
===
select b.DIC_VALUE 
from BAS_DIC b 
where b.DIC_CODE = #code#
and upper(b.DIC_TEXT) like #text#  ESCAPE '/'

==> fine-web-0.0.2-20220913.113206-173.jar: beetlsql/base/dic.md <==
select
===
select @pageTag(){
T.*,
GETDICNAME('DATA_STATUS', T.IS_ENABLE) AS ENABLE_NAME,
GETDICNAME('DIC_TYPE', T.DIC_TYPE) AS DIC_TYPE_NAME,
NVL(S1.USENUM,0)AS USENUM
 @}
FROM BAS_DIC T
LEFT JOIN (SELECT S.DIC_CODE, COUNT(S.DIC_CODE) AS USENUM
              FROM GEN_PANEL_ITEM S
             WHERE S.DIC_CODE IS NOT NULL
             GROUP BY S.DIC_CODE) S1
  ON S1.DIC_CODE = T.DIC_CODE
@where(){ 
	@if(!isEmpty(typeId)){
			and t.type_id=#typeId#
	@}
	@if(!isEmpty(search)){
		and ( upper(t.dic_code) like #search# ESCAPE '/' 
		or upper(t.dic_name) like  #search#  ESCAPE '/' 
		or upper(t.dic_value) like #search#  ESCAPE '/' 
		or upper(t.dic_text) like #search#  ESCAPE '/' 
		or upper(t.memo) like #search#  ESCAPE '/' )
	@}
@}
ORDER BY T.DIC_CODE, t.is_enable,T.DISPLAY_NO, T.DIC_VALUE


findByTypeId
===
select * from BAS_DIC t where t.type_id=#typeId#




pageAllType
===
select @pageTag(){
t.*,
GETDICNAME('IS_OR_NOT', T.FLAG) AS FLAG_TEXT,
GETDICNAME('IS_OR_NOT', T.USER_EDIT) AS USER_EDIT_TEXT,
GETDICNAME('DIC_TYPE', T.DIC_TYPE) AS DIC_TYPE_TEXT,
p.name business_Type,
NVL(S1.USENUM,0)AS USENUM
@}
 from BAS_DIC_TYPE t
LEFT JOIN (SELECT S.DIC_CODE, COUNT(S.DIC_CODE) AS USENUM
              FROM GEN_PANEL_ITEM S
             WHERE S.DIC_CODE IS NOT NULL
             GROUP BY S.DIC_CODE) S1
  ON S1.DIC_CODE = T.DIC_CODE
 left join STF_BUSINESS_TYPE p on p.res_id = t.business_Type_Id
 @if(!isEmpty(search)){
		,(
		(select x.dic_code from BAS_DIC_TYPE x where upper(x.dic_code) like #search#  ESCAPE '/' )
		union 
		(select x.dic_code from BAS_DIC_TYPE x where upper(x.dic_name) like #search#  ESCAPE '/' )
		union 
		(select x.dic_code from BAS_DIC_TYPE x where upper(x.RMK) like #search#  ESCAPE '/' )
		union 
		(select x.dic_code from BAS_DIC_TYPE x where upper(x.RMK) like #search#  ESCAPE '/' )
		union 
		(select d.dic_code from bas_dic d where upper(d.dic_text) like #search#  ESCAPE '/' or upper(d.dic_value) like #search#  ESCAPE '/' )
		) x 
	@}
 where t.is_use='Y'
 @if(!isEmpty(search)){
	 and t.dic_code =x.dic_code
 @}
@if(!isEmpty(businessTypeId)){
	and t.business_Type_Id = #businessTypeId#
@}
 
 ORDER BY T.ord_By
 
 
 
getWbsType
===
select 
       t.DIC_ID ID，
       t.DIC_VALUE VALUE,
       t.DIC_TEXT TEXT
       from BAS_DIC t
       where t.DIC_CODE = 'WBS_TYPE'
       @if(!isEmpty(id)){
       		and  t.DIC_VALUE >= #id#
       	@}
       	
getComboByDicValues
===
select 
	t.DIC_VALUE as value,
	t.DIC_TEXT as text
from bas_dic t
where t.IS_ENABLE =1
and t.DIC_CODE ='ASSETS_TYPE_ONE'
@if(!isEmpty(ids)){
  and t.DIC_VALUE in (#join(ids)# )
@}
